---
name: Запыт новых магчымасцяў
about: Прапануйце ідэю для нашага праекту
title: ''
labels: ''
assignees: ''

---
**Якія задачы дапаможа вырашаць новая магчымасць? Раскажыце, калі ласка.**
Яснае і паслядоўнае апісанне таго, што не так з цяперашняй версіяй. Напрыклад "Мяне заўжды дратавала [...]"

**Апішыце якія магчымасці вы б хацелі атрымаць**
Ясна і паслядоўна апішыце што мусіць стацца, каб вырашыць апісаную вышэй праблему.

**Ці існуюць нейкія альтэрнатыўныя спосабы вырашыць праблему?**
Караценька і змястоўна апішыце якія яшчэ могуць быць альтэрнатыўныя спосабы даць рады праблеме. Калі нейкія ёсць.

**Дадатак**
Напішыце ўсё астатняе, што на вашую думку тычыцца гэтай праблемы. Не стрымлівайце сябе.
